@@ -54,15 +54,15 @@ import java.sql.Connection;
 import java.sql.PreparedStatement;
 import java.sql.SQLException;
 import java.util.Map;
+import com.openexchange.database.Databases;
 import com.openexchange.exception.OXException;
 import com.openexchange.groupware.container.Contact;
 import com.openexchange.groupware.ldap.User;
-import com.openexchange.tools.sql.DBUtils;
 import com.openexchange.user.copy.CopyUserTaskService;
 import com.openexchange.user.copy.ObjectMapping;
 import com.openexchange.user.copy.UserCopyExceptionCodes;
 import com.openexchange.user.copy.internal.CopyTools;
-import com.openexchange.user.copy.internal.calendar.CalendarCopyTask;
+import com.openexchange.user.copy.internal.chronos.ChronosCopyTask;
 import com.openexchange.user.copy.internal.connection.ConnectionFetcherTask;
 import com.openexchange.user.copy.internal.contact.ContactCopyTask;
 import com.openexchange.user.copy.internal.context.ContextLoadTask;
@@ -99,7 +99,7 @@ public class AdditionalCopyTask implements CopyUserTaskService {
             ContextLoadTask.class.getName(),
             ConnectionFetcherTask.class.getName(),
             FolderCopyTask.class.getName(),
-            CalendarCopyTask.class.getName(),
+            ChronosCopyTask.class.getName(),
             ContactCopyTask.class.getName(),
             TaskCopyTask.class.getName()
         };
@@ -153,7 +153,7 @@ public class AdditionalCopyTask implements CopyUserTaskService {
         } catch (final SQLException e) {
             throw UserCopyExceptionCodes.SQL_PROBLEM.create(e);
         } finally {
-            DBUtils.closeSQLStuff(stmt);
+            Databases.closeSQLStuff(stmt);
         }
     }
 
